"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLegacyReserveAmount = exports.getLegacyModuleEntry = void 0;
const lisk_codec_1 = require("@liskhq/lisk-codec");
const constants_1 = require("../constants");
const schemas_1 = require("../schemas");
const AMOUNT_ZERO = BigInt('0');
let legacyReserveAmount = AMOUNT_ZERO;
const getLegacyModuleEntry = async (encodedUnregisteredAddresses, legacyReserveAccount) => {
    legacyReserveAmount = legacyReserveAccount ? legacyReserveAccount.token.balance : AMOUNT_ZERO;
    const { unregisteredAddresses } = await lisk_codec_1.codec.decode(schemas_1.unregisteredAddressesSchema, encodedUnregisteredAddresses);
    const legacyAccounts = unregisteredAddresses.map(account => {
        legacyReserveAmount += BigInt(account.balance);
        return {
            address: account.address,
            balance: String(account.balance),
        };
    });
    const sortedLegacyAccounts = legacyAccounts
        .sort((a, b) => a.address.compare(b.address))
        .map(entry => ({
        ...entry,
        address: entry.address.toString('hex'),
    }));
    return {
        module: constants_1.MODULE_NAME_LEGACY,
        data: { accounts: sortedLegacyAccounts },
        schema: schemas_1.genesisLegacyStoreSchema,
    };
};
exports.getLegacyModuleEntry = getLegacyModuleEntry;
const getLegacyReserveAmount = () => legacyReserveAmount;
exports.getLegacyReserveAmount = getLegacyReserveAmount;
//# sourceMappingURL=legacy.js.map