"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeGenesisBlock = exports.copyGenesisBlock = exports.writeGenesisAssets = exports.createGenesisBlock = exports.createChecksum = exports.getGenesisBlockCreateCommand = void 0;
const tslib_1 = require("tslib");
const crypto = tslib_1.__importStar(require("crypto"));
const fs = tslib_1.__importStar(require("fs-extra"));
const path_1 = tslib_1.__importDefault(require("path"));
const constants_1 = require("../constants");
const process_1 = require("./process");
const fs_1 = require("./fs");
const exception_1 = require("./exception");
BigInt.prototype.toJSON = function () {
    return this.toString();
};
Buffer.prototype.toJSON = function () {
    return this.toString('hex');
};
let genesisBlockCreateCommand;
const getGenesisBlockCreateCommand = () => genesisBlockCreateCommand;
exports.getGenesisBlockCreateCommand = getGenesisBlockCreateCommand;
const createChecksum = async (filePath) => {
    const fileStream = fs.createReadStream(filePath);
    const dataHash = crypto.createHash('sha256');
    const fileHash = await new Promise((resolve, reject) => {
        fileStream.on('data', (datum) => {
            dataHash.update(datum);
        });
        fileStream.on('error', error => {
            reject(error);
        });
        fileStream.on('end', () => {
            resolve(dataHash.digest());
        });
    });
    return fileHash.toString('hex');
};
exports.createChecksum = createChecksum;
const createGenesisBlock = async (_this, network, configFilepath, outputDir, blockHeaderAtSnapshotHeight) => {
    try {
        const height = blockHeaderAtSnapshotHeight.height + 1;
        const timestamp = blockHeaderAtSnapshotHeight.timestamp + constants_1.SNAPSHOT_TIME_GAP;
        const previousBlockID = blockHeaderAtSnapshotHeight.id.toString('hex');
        genesisBlockCreateCommand = `lisk-core genesis-block:create --network ${network} --config=${configFilepath} --output=${outputDir} --assets-file=${outputDir}/genesis_assets.json --height=${height} --previous-block-id=${previousBlockID} --timestamp=${timestamp} --export-json`;
        _this.log(`\nExecuting the following command to generate the genesis block:\n${genesisBlockCreateCommand}`);
        await (0, process_1.execAsync)(genesisBlockCreateCommand);
    }
    catch (error) {
        throw new exception_1.MigratorException(`Failed to create genesis block.\nError: ${error.message}`, 2);
    }
};
exports.createGenesisBlock = createGenesisBlock;
const writeGenesisAssets = async (genesisAssets, outputDir) => {
    const genesisAssetsJsonFilepath = path_1.default.resolve(outputDir, constants_1.FILE_NAME.GENESIS_ASSETS);
    fs.writeFileSync(genesisAssetsJsonFilepath, JSON.stringify({ assets: genesisAssets }, null, '\t'));
};
exports.writeGenesisAssets = writeGenesisAssets;
const copyGenesisBlock = async (currGenesisBlockFilepath, liskCoreV4ConfigPath) => (0, fs_1.copyFile)(currGenesisBlockFilepath, liskCoreV4ConfigPath);
exports.copyGenesisBlock = copyGenesisBlock;
const writeGenesisBlock = async (outputDir) => {
    const genesisBlockBlobFilepath = path_1.default.resolve(outputDir, constants_1.FILE_NAME.GENESIS_BLOCK_BLOB);
    const genesisBlockBlobHash = await (0, exports.createChecksum)(genesisBlockBlobFilepath);
    fs.writeFileSync(path_1.default.resolve(outputDir, `${constants_1.FILE_NAME.GENESIS_BLOCK_BLOB}.SHA256`), genesisBlockBlobHash);
    await (0, fs_1.createTarball)(genesisBlockBlobFilepath, outputDir);
    const genesisBlockBlobTarballHash = await (0, exports.createChecksum)(`${genesisBlockBlobFilepath}.tar.gz`);
    fs.writeFileSync(path_1.default.resolve(outputDir, `${constants_1.FILE_NAME.GENESIS_BLOCK_BLOB}.tar.gz.SHA256`), genesisBlockBlobTarballHash);
    const genesisBlockJsonFilepath = path_1.default.resolve(outputDir, constants_1.FILE_NAME.GENESIS_BLOCK_JSON);
    const genesisBlockJsonHash = await (0, exports.createChecksum)(genesisBlockJsonFilepath);
    fs.writeFileSync(path_1.default.resolve(outputDir, `${constants_1.FILE_NAME.GENESIS_BLOCK_JSON}.SHA256`), genesisBlockJsonHash);
    await (0, fs_1.createTarball)(genesisBlockJsonFilepath, outputDir);
    const genesisBlockJsonTarBallHash = await (0, exports.createChecksum)(`${genesisBlockJsonFilepath}.tar.gz`);
    fs.writeFileSync(path_1.default.resolve(outputDir, `${constants_1.FILE_NAME.GENESIS_BLOCK_JSON}.tar.gz.SHA256`), genesisBlockJsonTarBallHash);
};
exports.writeGenesisBlock = writeGenesisBlock;
//# sourceMappingURL=genesis_block.js.map